# -*- coding: utf-8 -*-
#
# dit documentation build configuration file, created by
# sphinx-quickstart on Thu Oct 31 02:07:43 2013.
#
# This file is execfile()d with the current directory set to its containing dir.
#
# Note that not all possible configuration values are present in this
# autogenerated file.
#
# All configuration values have a default; values that are commented out
# serve to show the default.

import sys, os

# environment variable to know if the docs are being built on rtd.
on_rtd = os.environ.get('READTHEDOCS', None) == 'True'

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#sys.path.insert(0, os.path.abspath('.'))

# -- General configuration -----------------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
needs_sphinx = '1.3'

# All our documentation is python.
primary_domain = 'py'

# Add any Sphinx extension module names here, as strings. They can be extensions
# coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
extensions = ['releases',
              'sphinx.ext.autodoc',
              'sphinx.ext.intersphinx',
              'sphinx.ext.coverage',
              'sphinx.ext.mathjax',
              'sphinx.ext.todo',
              'sphinx.ext.viewcode',
              'sphinx.ext.napoleon',
              'sphinxcontrib.bibtex',
              'IPython.sphinxext.ipython_console_highlighting',
              'IPython.sphinxext.ipython_directive',
              'matplotlib.sphinxext.plot_directive',
             ]

ipython_mplbackend = 'agg'
ipython_execlines = ['from __future__ import division, print_function',
                     'import numpy as np',
                     'import matplotlib.pyplot as plt',
                     'plt.rcParams["figure.figsize"] = (8, 6)',
                     'plt.rcParams["savefig.facecolor"] = (1, 1, 1, 0)',
                     'import dit',
                    ]
ipython_savefig_dir = 'images/'

# Use our local configuration for mathjax:
mathjax_path = "https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.4/MathJax.js?config=TeX-MML-AM_CHTML,http://docs.dit.io/en/latest/_static/dit_mathjax.js"

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# The suffix of source filenames.
source_suffix = '.rst'

# The encoding of source files.
#source_encoding = 'utf-8-sig'

# The master toctree document.
master_doc = 'index'

# General information about the project.
project = u'dit'
copyright = u'2013-2018, dit contributors'

# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
#
# The short X.Y version.
import dit
version = dit.__version__
# The full version, including alpha/beta/rc tags.
release = dit.__version__

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#language = None

# There are two options for replacing |today|: either, you set today to some
# non-false value, then it is used:
#today = ''
# Else, today_fmt is used as the format for a strftime call.
#today_fmt = '%B %d, %Y'

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
exclude_patterns = ['_build']

# The reST default role (used for this markup: `text`) to use for all documents.
#default_role = None

# If true, '()' will be appended to :func: etc. cross-reference text.
#add_function_parentheses = True

# If true, the current module name will be prepended to all description
# unit titles (such as .. function::).
add_module_names = False

# If true, sectionauthor and moduleauthor directives will be shown in the
# output. They are ignored by default.
#show_authors = False

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'sphinx'

# A list of ignored prefixes for module index sorting.
modindex_common_prefix = ['dit.']

# Only show todos for local builds, not on the official docs.
todo_include_todos = not on_rtd

# changelog-related items:
releases_release_uri = "https://github.com/dit/dit/tree/%s"
releases_issue_uri = "https://github.com/dit/dit/issues/%s"

# -- Options for HTML output ---------------------------------------------------

# Add any paths that contain custom themes here, relative to this directory.
html_theme_path = ["_themes"]

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
if not on_rtd:
    html_theme = 'sphinx_rtd_theme'

# Theme options are theme-specific and customize the look and feel of a theme
# further.  For a list of options available for each theme, see the
# documentation.
#html_theme_options = {}

# The name for this set of Sphinx documents.  If None, it defaults to
# "<project> v<release> documentation".
#html_title = None

# A shorter title for the navigation bar.  Default is the same as html_title.
#html_short_title = None

# The name of an image file (relative to this directory) to place at the top
# of the sidebar.
#html_logo = None

# The name of an image file (within the static path) to use as favicon of the
# docs.  This file should be a Windows icon file (.ico) being 16x16 or 32x32
# pixels large.
#html_favicon = None

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

# If not '', a 'Last updated on:' timestamp is inserted at every page bottom,
# using the given strftime format.
#html_last_updated_fmt = '%b %d, %Y'

# If true, SmartyPants will be used to convert quotes and dashes to
# typographically correct entities.
#html_use_smartypants = True

# Custom sidebar templates, maps document names to template names.
#html_sidebars = {}

# Additional templates that should be rendered to pages, maps page names to
# template names.
#html_additional_pages = {}

# If false, no module index is generated.
#html_domain_indices = True

# If false, no index is generated.
#html_use_index = True

# If true, the index is split into individual pages for each letter.
#html_split_index = False

# If true, links to the reST sources are added to the pages.
#html_show_sourcelink = True

# If true, "Created using Sphinx" is shown in the HTML footer. Default is True.
#html_show_sphinx = True

# If true, "(C) Copyright ..." is shown in the HTML footer. Default is True.
#html_show_copyright = True

# If true, an OpenSearch description file will be output, and all pages will
# contain a <link> tag referring to it.  The value of this option must be the
# base URL from which the finished HTML is served.
#html_use_opensearch = ''

# This is the file name suffix for HTML files (e.g. ".xhtml").
#html_file_suffix = None

# Output file base name for HTML help builder.
htmlhelp_basename = 'ditdoc'


# -- Options for LaTeX output --------------------------------------------------

macros = r'''
\newcommand{\op}[2{\ensuremath{\operatorname{#1}\left[#2\right]}}

\renewcommand{\H}[1]  {\op{H}{#1}}   % No more Erd\H{o}s

\newcommand{\I}[1]    {\op{I}{#1}}
\newcommand{\T}[1]    {\op{T}{#1}}
\newcommand{\B}[1]    {\op{B}{#1}}
\newcommand{\J}[1]    {\op{J}{#1}}

\newcommand{\R}[1]    {\op{R}{#1}}
\newcommand{\II}[1]   {\op{II}{#1}}
\newcommand{\TSE}[1]  {\op{TSE}{#1}}

\newcommand{\K}[1]    {\op{K}{#1}}
\newcommand{\C}[1]    {\op{C}{#1}}
\newcommand{\G}[1]    {\op{G}{#1}}
\newcommand{\F}[1]    {\op{F}{#1}}
\newcommand{\M}[1]    {\op{M}{#1}}

\renewcommand{\P}[1]  {\op{P}{#1}}
\newcommand{\X}[1]    {\op{X}{#1}}
\newcommand{\CRE}[1]  {\op{\mathcal{E}}{#1}}
\newcommand{\GCRE}[1] {\op{\mathcal{E^\prime}}{#1}}
\newcommand{\RE}[2]   {\op{H_{#1}}{#2}}
\newcommand{\TE}[2]   {\op{S_{#1}}{#2}}
\newcommand{\L}[1]    {\op{L}{#1}}
\newcommand{\ID}[1]   {\op{I_D}{#1}}

\newcommand{\xH}[1]   {\op{xH}{#1}}
\newcommand{\DKL}[1]  {\op{D_{KL}}{#1}}
\newcommand{\JSD}[1]  {\op{D_{JS}}{#1}}

\newcommand{\Icap}[1] {\op{I_{\cap}}{#1}}
\newcommand{\Imin}[1] {\op{I_{min}}{#1}}
\newcommand{\Immi}[1] {\op{I_{MMI}}{#1}}
\newcommand{\Iwedge}[1] {\op{I_{\wedge}}{#1}}
\newcommand{\Iproj}[1] {\op{I_{proj}}{#1}}
\newcommand{\Ibroja}[1] {\op{I_{BROJA}}{#1}}
\newcommand{\Iccs}[1] {\op{I_{ccs}}{#1}}
\newcommand{\Ida}[1] {\op{I_{\downarrow}}{#1}}
\newcommand{\Idda}[1] {\op{I_{\Downarrow}}{#1}}
\newcommand{\Idep}[1] {\op{I_{dep}}{#1}}
\newcommand{\Hpart}[1] {\op{H_{\partial}}{#1}}
\newcommand{\Hcs}[1] {\op{H_{cs}}{#1}}
\newcommand{\Irav}[1] {\op{I_{RAV}}{#1}}
\newcommand{\Irr}[1] {\op{I_{RR}}{#1}}

\newcommand{\meet} {\curlywedge}
\newcommand{\join} {\curlyvee}
\newcommand{\iless}{\preceq}
\newcommand{\imore}{\succeq}
\newcommand{\ieq}  {\cong}
\newcommand{\mss}  {\searrow}

\DeclareMathOperator*{\meetop}{\scalerel*{\meet}{\textstyle\sum}}
\DeclareMathOperator*{\joinop}{\scalerel*{\join}{\textstyle\sum}}

\newcommand{\ind}{\mathrel{\text{\scalebox{1.07}{$\perp\mkern-10mu\perp$}}}}
'''

latex_elements = {
# The paper size ('letterpaper' or 'a4paper').
#'papersize': 'letterpaper',

# The font size ('10pt', '11pt' or '12pt').
#'pointsize': '10pt',

# Additional stuff for the LaTeX preamble.
'preamble': r'''
\usepackage{amsmath}
\usepackage{amssymb}
\usepackage{nicefrac}
''' + macros,
}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title, author, documentclass [howto/manual]).
latex_documents = [
  ('index', 'dit.tex', u'dit Documentation',
   u'dit Contributors', 'manual'),
]

# The name of an image file (relative to this directory) to place at the top of
# the title page.
#latex_logo = None

# For "manual" documents, if this is true, then toplevel headings are parts,
# not chapters.
#latex_use_parts = False

# If true, show page references after internal links.
#latex_show_pagerefs = False

# If true, show URL addresses after external links.
#latex_show_urls = False

# Documents to append as an appendix to all manuals.
#latex_appendices = []

# If false, no module index is generated.
#latex_domain_indices = True


# -- Options for manual page output --------------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [
    ('index', 'dit', u'dit Documentation',
     [u'dit Contributors'], 1)
]

# If true, show URL addresses after external links.
#man_show_urls = False


# -- Options for Texinfo output ------------------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
  ('index', 'dit', u'dit Documentation',
   u'dit Contributors', 'dit', 'Discrete Information Theory in Python.',
   'Science'),
]

# Documents to append as an appendix to all manuals.
#texinfo_appendices = []

# If false, no module index is generated.
#texinfo_domain_indices = True

# How to display URL addresses: 'footnote', 'no', or 'inline'.
#texinfo_show_urls = 'footnote'


# Example configuration for intersphinx: refer to the Python standard library.
intersphinx_mapping = {'http://docs.python.org/': None}
